@@ -5,9 +5,6 @@ mod server;
 mod token;
 mod util;
 
-#[cfg(test)]
-mod test;
-
 pub use self::client::*;
 pub use self::server::*;
 pub use self::token::*;
